@@ -21,13 +21,13 @@ import littlechef
 from lib import credentials
 
 
-def install(distro_type, distro, gems):
+def install(distro_type, distro, gems, version):
     with credentials():
         if distro_type == "debian":
             if gems == "yes":
                 _gem_apt_install()
             else:
-                _apt_install(distro)
+                _apt_install(distro, version)
         elif distro_type == "rpm":
             if gems == "yes":
                 _gem_rpm_install()
@@ -42,26 +42,30 @@ def install(distro_type, distro, gems):
 def configure():
     """Deploy chef-solo specific files"""
     with credentials():
-        sudo('mkdir -p {0}'.format(littlechef.node_work_path))
         sudo('mkdir -p {0}/cache'.format(littlechef.node_work_path))
         sudo('umask 0377; touch solo.rb')
-        append('solo.rb', 'file_cache_path "{0}/cache"'.format(
-            littlechef.node_work_path), use_sudo=True)
+        text = ""
+        text += 'file_cache_path "{0}/cache"'.format(littlechef.node_work_path)
+        text += "\n"
         reversed_cookbook_paths = littlechef.cookbook_paths[:]
         reversed_cookbook_paths.reverse()
         cookbook_paths_line = 'cookbook_path [{0}]'.format(', '.join(
-            ['''"{0}/{1}"'''.format(littlechef.node_work_path, x) \
+            ['"{0}/{1}"'.format(littlechef.node_work_path, x) \
                 for x in reversed_cookbook_paths]))
-        append('solo.rb', cookbook_paths_line, use_sudo=True)
-        append('solo.rb', 'role_path "{0}/roles"'.format(
-            littlechef.node_work_path), use_sudo=True)
+        text += cookbook_paths_line + "\n"
+        text += cookbook_paths_line + "\n"
+        text += 'role_path "{0}/roles"'.format(
+                                            littlechef.node_work_path) + "\n"
+        text += 'data_bag_path "{0}/data_bags"'.format(
+                                            littlechef.node_work_path) + "\n"
+        append('solo.rb', text, use_sudo=True)
         sudo('mkdir -p /etc/chef')
         sudo('mv solo.rb /etc/chef/')
 
 
 def check_distro():
     """Check that the given distro is supported and return the distro type"""
-    debian_distros = ['sid', 'squeeze', 'lenny']
+    debian_distros = ['wheezy', 'squeeze', 'lenny']
     ubuntu_distros = ['maverick', 'lucid', 'karmic', 'jaunty', 'hardy']
     rpm_distros = ['centos', 'rhel', 'sl']
 
@@ -74,8 +78,11 @@ def check_distro():
         elif 'Debian GNU/Linux 6.0' in output:
             distro = "squeeze"
             distro_type = "debian"
+        elif 'Debian GNU/Linux wheezy' in output:
+            distro = "wheezy"
+            distro_type = "debian"
         elif 'Ubuntu' in output:
-            distro = sudo('lsb_release -c').split('\t')[-1]
+            distro = sudo('lsb_release -cs')
             distro_type = "debian"
         elif 'CentOS' in output:
             distro = "CentOS"
@@ -102,11 +109,13 @@ def check_distro():
 def _gem_install():
     """Install Chef from gems"""
     # Install RubyGems from Source
-    run('wget http://production.cf.rubygems.org/rubygems/rubygems-1.3.7.tgz')
-    run('tar zxf rubygems-1.3.7.tgz')
-    with cd("rubygems-1.3.7"):
-        sudo('ruby setup.rb --no-format-executable')
-    sudo('rm -rf rubygems-1.3.7 rubygems-1.3.7.tgz')
+    rubygems_version = "1.7.2"
+    run('wget http://production.cf.rubygems.org/rubygems/rubygems-{0}.tgz'
+        .format(rubygems_version))
+    run('tar zxf rubygems-{0}.tgz'.format(rubygems_version))
+    with cd('rubygems-{0}'.format(rubygems_version)):
+        sudo('ruby setup.rb --no-format-executable'.format(rubygems_version))
+    sudo('rm -rf rubygems-{0} rubygems-{0}.tgz'.format(rubygems_version))
     sudo('gem install --no-rdoc --no-ri chef')
 
 
@@ -126,14 +135,19 @@ def _gem_rpm_install():
     _gem_install()
 
 
-def _apt_install(distro):
+def _apt_install(distro, version):
     """Install Chef for debian based distros"""
     with hide('stdout'):
         # we may not be able to install wget withtout 'apt-get update' first
         sudo('apt-get update')
     sudo('apt-get --yes install wget')
+    if version == "0.9":
+        version = ""
+    else:
+        version = "-" + version
     append('opscode.list',
-        'deb http://apt.opscode.com/ {0} main'.format(distro), use_sudo=True)
+        'deb http://apt.opscode.com/ {0}{1} main'.format(distro, version),
+            use_sudo=True)
     sudo('mv opscode.list /etc/apt/sources.list.d/')
     gpg_key = "http://apt.opscode.com/packages@opscode.com.gpg.key"
     sudo('wget -qO - {0} | sudo apt-key add -'.format(gpg_key))
